%define ALD_Ver		2.0

#USE gcc-7.5.0

%define OrgName zlib
%define mC_Version 1.2.4s

Name:         mC-%{OrgName}
License:      (C) 1995-2004 Jean-loup Gailly and Mark Adler
Summary:      GNU zlib is a general purpose data compression library
Version:      1.2.11
Release:      %{mC_Version}.0

Source: %{OrgName}-%{version}.tar.xz
Source2: %{OrgName}-%{version}-patches.tgz

%define DestDir /Embedded/mC/%{mC_Version}
%define _prefix /usr/mC/%{mC_Version}

# -----------------------------------------------------
%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}/mC/%{mC_Version}
%define _CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%endif

# -----------------------------------------------------

%if %{have_auto_local}
%define __os_install_post %{nil}
%endif

%if %{_CROSS}
%define CrossPath /cross/%{_target_cpu}
%else
%define CrossPath %{nil}
%endif

#------------------ CROSS DIR --------------------

%define target %{_arch}-linux-musl
%define docdir %{_defaultdocdir}/%{OrgName}

# ------------------- description ------------------------------------
%description
This package contains the GNU general purpose data compression library

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}

tar -xaf %SOURCE2

# https://github.com/madler/zlib/pull/210
patch -p1<patches/zlib-1.2.5-minizip-fixuncrypt.patch
%ifarch s390 s390x
# resolves: #805113
patch -p1<patches/zlib-1.2.11-optimized-s390.patch
%endif
# IBM Z optimalizations
patch -p1<patches/zlib-1.2.11-IBM-Z-hw-accelrated-deflate-s390x.patch
# IBM CRC32 optimalization for POWER archs
patch -p1<patches/zlib-1.2.11-optimized-CRC32-framework.patch
# fixed firefox crash + added test case
patch -p1<patches/zlib-1.2.11-firefox-crash-fix.patch
# fixed covscan issues
patch -p1<patches/zlib-1.2.11-covscan-issues.patch
# fix for IBM Z optimalizations
patch -p1<patches/zlib-1.2.11-IBM-Z-hw-accelrated-deflate-fix.patch
# permit a deflateParams() parameter change
patch -p1<patches/zlib-1.2.11-permit-deflateParams-change.patch
# fixed DFLTCC compression level switching issues
# enabled HW compression for compression levels 1 through 6
patch -p1<patches/zlib-1.2.11-IBM-DFLTCC-compression-level-switching-issues.patch
# fixed inflateSyncPoint() bad return value on z15
patch -p1<patches/zlib-1.2.11-inflateSyncPoint-return-value-fix.patch
# fixed issues found by covscan for rhel-9
# ref: https://github.com/madler/zlib/pull/554
patch -p1<patches/zlib-1.2.11-covscan-issues-rhel9.patch
# Fix for s390x vectorize CRC32
patch -p1<patches/zlib-1.2.11-s390x-vectorize-crc32.patch

patch -p0<patches/pkgconfig.patch

# ------------------- Build ------------------------------------------
%Build
export PATH=$PATH:%{CrossPath}%{_prefix}/bin
export GCC_NoHostPath=d

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os -fno-tree-loop-optimize -fno-tree-dominator-opts -fno-strength-reduce"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -Os -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables -ffunction-sections -fdata-sections"
export CFLAGS="$OPTFLAGS -std=gnu99"
export LDFLAGS="-Wl,--gc-sections"
export CC="%{target}-gcc"

./configure \
	--prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--includedir=%{_includedir} \
	--static \
	>FConfigure_log.txt

make >FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
export PATH=$PATH:%{CrossPath}%{_prefix}/bin
export GCC_NoHostPath=d

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

%makeinstall
cp FAQ README $RPM_BUILD_ROOT%{docdir}/

rm -r $RPM_BUILD_ROOT%{_mandir}

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-target_platform=%{target}-
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean
%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%files
%{_includedir}
%{_libdir}/*.a
%{docdir}
%{_libdir}/pkgconfig
